# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ApimodelGetListOfConfigurationsV2Response
from ..models import ApimodelSaveConfigurationV2Request
from ..models import ApimodelSaveConfigurationV2Response
from ..models import ApimodelSaveSecretConfigurationV2Request
from ..models import ApimodelUpdateConfigurationV2Request
from ..models import ApimodelUpdateConfigurationV2Response
from ..models import ApimodelUpdateSecretConfigurationV2Request
from ..models import ResponseErrorResponse

from ..operations.configuration_v2 import DeleteSecretV2
from ..operations.configuration_v2 import DeleteVariableV2
from ..operations.configuration_v2 import GetListOfSecretsV2
from ..operations.configuration_v2 import GetListOfVariablesV2
from ..operations.configuration_v2 import SaveSecretV2
from ..operations.configuration_v2 import SaveVariableV2
from ..operations.configuration_v2 import UpdateSecretV2
from ..operations.configuration_v2 import UpdateVariableV2


@same_doc_as(DeleteSecretV2)
def delete_secret_v2(
    app: str,
    config_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete an environment secret (DeleteSecretV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:SECRET [DELETE]`

    Delete an environment secret by its config id

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/secrets/{configId}

        method: DELETE

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        config_id: (configId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content -

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteSecretV2.create(
        app=app,
        config_id=config_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteSecretV2)
async def delete_secret_v2_async(
    app: str,
    config_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete an environment secret (DeleteSecretV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:SECRET [DELETE]`

    Delete an environment secret by its config id

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/secrets/{configId}

        method: DELETE

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        config_id: (configId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content -

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteSecretV2.create(
        app=app,
        config_id=config_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteVariableV2)
def delete_variable_v2(
    app: str,
    config_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete an environment variable (DeleteVariableV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:VARIABLE [DELETE]`

    Delete an environment variable by its config id

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/variables/{configId}

        method: DELETE

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        config_id: (configId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content -

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteVariableV2.create(
        app=app,
        config_id=config_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteVariableV2)
async def delete_variable_v2_async(
    app: str,
    config_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete an environment variable (DeleteVariableV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:VARIABLE [DELETE]`

    Delete an environment variable by its config id

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/variables/{configId}

        method: DELETE

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        config_id: (configId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content -

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteVariableV2.create(
        app=app,
        config_id=config_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetListOfSecretsV2)
def get_list_of_secrets_v2(
    app: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get list of environment secrets (GetListOfSecretsV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:SECRET [READ]`

    Get list of environment secrets per app
    Available Deployment Status:
    `deployed` = app config is already deployed
    `undeployed` = app config is not deployed yet and need restart and deploy of the app to be deployed

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/secrets

        method: GET

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ApimodelGetListOfConfigurationsV2Response

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetListOfSecretsV2.create(
        app=app,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetListOfSecretsV2)
async def get_list_of_secrets_v2_async(
    app: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get list of environment secrets (GetListOfSecretsV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:SECRET [READ]`

    Get list of environment secrets per app
    Available Deployment Status:
    `deployed` = app config is already deployed
    `undeployed` = app config is not deployed yet and need restart and deploy of the app to be deployed

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/secrets

        method: GET

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ApimodelGetListOfConfigurationsV2Response

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetListOfSecretsV2.create(
        app=app,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetListOfVariablesV2)
def get_list_of_variables_v2(
    app: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get list of environment variables (GetListOfVariablesV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:VARIABLE [READ]`

    Get list of environment variables per app
    Available Deployment Status:
    `deployed` = app config is already deployed
    `undeployed` = app config is not deployed yet and need restart and deploy of the app to be deployed

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/variables

        method: GET

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ApimodelGetListOfConfigurationsV2Response

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetListOfVariablesV2.create(
        app=app,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetListOfVariablesV2)
async def get_list_of_variables_v2_async(
    app: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get list of environment variables (GetListOfVariablesV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:VARIABLE [READ]`

    Get list of environment variables per app
    Available Deployment Status:
    `deployed` = app config is already deployed
    `undeployed` = app config is not deployed yet and need restart and deploy of the app to be deployed

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/variables

        method: GET

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ApimodelGetListOfConfigurationsV2Response

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetListOfVariablesV2.create(
        app=app,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SaveSecretV2)
def save_secret_v2(
    app: str,
    body: ApimodelSaveSecretConfigurationV2Request,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Save an environment secret (SaveSecretV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:SECRET [CREATE]`

    Save an environment secret.
    Secret will always be masked.
    Request body:
    - configName : environment secret name - Required.
    - source : source of the configuration value (plaintext or ssm) - Required.
    - value : configuration value - Required.
    - description : description of the configuration - Optional.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/secrets

        method: POST

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelSaveSecretConfigurationV2Request in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelSaveConfigurationV2Response (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = SaveSecretV2.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SaveSecretV2)
async def save_secret_v2_async(
    app: str,
    body: ApimodelSaveSecretConfigurationV2Request,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Save an environment secret (SaveSecretV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:SECRET [CREATE]`

    Save an environment secret.
    Secret will always be masked.
    Request body:
    - configName : environment secret name - Required.
    - source : source of the configuration value (plaintext or ssm) - Required.
    - value : configuration value - Required.
    - description : description of the configuration - Optional.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/secrets

        method: POST

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelSaveSecretConfigurationV2Request in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelSaveConfigurationV2Response (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = SaveSecretV2.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SaveVariableV2)
def save_variable_v2(
    app: str,
    body: ApimodelSaveConfigurationV2Request,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Save an environment variable (SaveVariableV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:VARIABLE [CREATE]`

    Save an environment variable.
    Request body:
    - configName : environment variable name - Required.
    - source : source of the configuration value (plaintext or ssm) - Required.
    - value : configuration value - Required.
    - description : description of the configuration - Optional.
    - applyMask : mask the value in the Helm manifest for sensitive information (true or false) - Optional.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/variables

        method: POST

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelSaveConfigurationV2Request in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelSaveConfigurationV2Response (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = SaveVariableV2.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SaveVariableV2)
async def save_variable_v2_async(
    app: str,
    body: ApimodelSaveConfigurationV2Request,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Save an environment variable (SaveVariableV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:VARIABLE [CREATE]`

    Save an environment variable.
    Request body:
    - configName : environment variable name - Required.
    - source : source of the configuration value (plaintext or ssm) - Required.
    - value : configuration value - Required.
    - description : description of the configuration - Optional.
    - applyMask : mask the value in the Helm manifest for sensitive information (true or false) - Optional.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/variables

        method: POST

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelSaveConfigurationV2Request in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelSaveConfigurationV2Response (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = SaveVariableV2.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateSecretV2)
def update_secret_v2(
    app: str,
    body: ApimodelUpdateSecretConfigurationV2Request,
    config_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update an environment secret (UpdateSecretV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:SECRET [UPDATE]`

    Update an environment secret.
    Secret will always be masked.
    Request body:
    - value : configuration value - Required.
    - description : description of the configuration - Optional.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/secrets/{configId}

        method: PUT

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelUpdateSecretConfigurationV2Request in body

        app: (app) REQUIRED str in path

        config_id: (configId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelUpdateConfigurationV2Response (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateSecretV2.create(
        app=app,
        body=body,
        config_id=config_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateSecretV2)
async def update_secret_v2_async(
    app: str,
    body: ApimodelUpdateSecretConfigurationV2Request,
    config_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update an environment secret (UpdateSecretV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:SECRET [UPDATE]`

    Update an environment secret.
    Secret will always be masked.
    Request body:
    - value : configuration value - Required.
    - description : description of the configuration - Optional.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/secrets/{configId}

        method: PUT

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelUpdateSecretConfigurationV2Request in body

        app: (app) REQUIRED str in path

        config_id: (configId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelUpdateConfigurationV2Response (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateSecretV2.create(
        app=app,
        body=body,
        config_id=config_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateVariableV2)
def update_variable_v2(
    app: str,
    body: ApimodelUpdateConfigurationV2Request,
    config_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update an environment variable (UpdateVariableV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:VARIABLE [UPDATE]`

    Update an environment variable.
    Request body:
    - value : configuration value - Required.
    - description : description of the configuration - Optional.
    - applyMask : mask the value in the Helm manifest for sensitive information (true or false) - Optional.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/variables/{configId}

        method: PUT

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelUpdateConfigurationV2Request in body

        app: (app) REQUIRED str in path

        config_id: (configId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelUpdateConfigurationV2Response (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateVariableV2.create(
        app=app,
        body=body,
        config_id=config_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateVariableV2)
async def update_variable_v2_async(
    app: str,
    body: ApimodelUpdateConfigurationV2Request,
    config_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update an environment variable (UpdateVariableV2)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:VARIABLE [UPDATE]`

    Update an environment variable.
    Request body:
    - value : configuration value - Required.
    - description : description of the configuration - Optional.
    - applyMask : mask the value in the Helm manifest for sensitive information (true or false) - Optional.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/variables/{configId}

        method: PUT

        tags: ["Configuration V2"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelUpdateConfigurationV2Request in body

        app: (app) REQUIRED str in path

        config_id: (configId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelUpdateConfigurationV2Response (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateVariableV2.create(
        app=app,
        body=body,
        config_id=config_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Legal Service."""

__version__ = "4.6.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._admin_user_agreement import indirect_bulk_accept_versioned_policy
from ._admin_user_agreement import indirect_bulk_accept_versioned_policy_async

from ._admin_user_eligibilities import admin_retrieve_eligibilities
from ._admin_user_eligibilities import admin_retrieve_eligibilities_async

from ._agreement import accept_versioned_policy
from ._agreement import accept_versioned_policy_async
from ._agreement import bulk_accept_versioned_policy
from ._agreement import bulk_accept_versioned_policy_async
from ._agreement import change_preference_consent
from ._agreement import change_preference_consent_async
from ._agreement import indirect_bulk_accept_versioned_policy_v2
from ._agreement import indirect_bulk_accept_versioned_policy_v2_async
from ._agreement import old_retrieve_accepted_agreements
from ._agreement import old_retrieve_accepted_agreements_async
from ._agreement import old_retrieve_all_users_by_policy_version
from ._agreement import old_retrieve_all_users_by_policy_version_async
from ._agreement import public_change_preference_consent
from ._agreement import public_change_preference_consent_async
from ._agreement import public_indirect_bulk_accept_versioned_policy
from ._agreement import public_indirect_bulk_accept_versioned_policy_async
from ._agreement import retrieve_agreements_public
from ._agreement import retrieve_agreements_public_async

from ._agreement_with_namespace import download_exported_agreements_in_csv
from ._agreement_with_namespace import download_exported_agreements_in_csv_async
from ._agreement_with_namespace import initiate_export_agreements_to_csv
from ._agreement_with_namespace import initiate_export_agreements_to_csv_async
from ._agreement_with_namespace import retrieve_accepted_agreements
from ._agreement_with_namespace import retrieve_accepted_agreements_async
from ._agreement_with_namespace import retrieve_accepted_agreements_for_multi_users
from ._agreement_with_namespace import (
    retrieve_accepted_agreements_for_multi_users_async,
)
from ._agreement_with_namespace import retrieve_all_users_by_policy_version
from ._agreement_with_namespace import retrieve_all_users_by_policy_version_async

from ._anonymization import anonymize_user_agreement
from ._anonymization import anonymize_user_agreement_async

from ._base_legal_policies import old_create_policy
from ._base_legal_policies import old_create_policy_async
from ._base_legal_policies import old_partial_update_policy
from ._base_legal_policies import old_partial_update_policy_async
from ._base_legal_policies import old_retrieve_all_policy_types
from ._base_legal_policies import old_retrieve_all_policy_types_async
from ._base_legal_policies import old_retrieve_policy_country
from ._base_legal_policies import old_retrieve_policy_country_async
from ._base_legal_policies import old_retrieve_single_policy
from ._base_legal_policies import old_retrieve_single_policy_async
from ._base_legal_policies import retrieve_all_legal_policies
from ._base_legal_policies import retrieve_all_legal_policies_async

from ._base_legal_policies_with_namespace import create_policy
from ._base_legal_policies_with_namespace import create_policy_async
from ._base_legal_policies_with_namespace import create_policy_under_base_policy
from ._base_legal_policies_with_namespace import create_policy_under_base_policy_async
from ._base_legal_policies_with_namespace import delete_base_policy
from ._base_legal_policies_with_namespace import delete_base_policy_async
from ._base_legal_policies_with_namespace import partial_update_policy
from ._base_legal_policies_with_namespace import partial_update_policy_async
from ._base_legal_policies_with_namespace import (
    retrieve_all_legal_policies_by_namespace,
)
from ._base_legal_policies_with_namespace import (
    retrieve_all_legal_policies_by_namespace_async,
)
from ._base_legal_policies_with_namespace import retrieve_all_policies_from_base_policy
from ._base_legal_policies_with_namespace import (
    retrieve_all_policies_from_base_policy_async,
)
from ._base_legal_policies_with_namespace import retrieve_all_policy_types
from ._base_legal_policies_with_namespace import retrieve_all_policy_types_async
from ._base_legal_policies_with_namespace import retrieve_policy_country
from ._base_legal_policies_with_namespace import retrieve_policy_country_async
from ._base_legal_policies_with_namespace import retrieve_single_policy
from ._base_legal_policies_with_namespace import retrieve_single_policy_async

from ._eligibilities import retrieve_eligibilities_public
from ._eligibilities import retrieve_eligibilities_public_async
from ._eligibilities import retrieve_eligibilities_public_indirect
from ._eligibilities import retrieve_eligibilities_public_indirect_async

from ._localized_policy_versions import old_create_localized_policy_version
from ._localized_policy_versions import old_create_localized_policy_version_async
from ._localized_policy_versions import (
    old_public_retrieve_single_localized_policy_version,
)
from ._localized_policy_versions import (
    old_public_retrieve_single_localized_policy_version_async,
)
from ._localized_policy_versions import old_request_presigned_url
from ._localized_policy_versions import old_request_presigned_url_async
from ._localized_policy_versions import old_retrieve_localized_policy_versions
from ._localized_policy_versions import old_retrieve_localized_policy_versions_async
from ._localized_policy_versions import old_retrieve_single_localized_policy_version
from ._localized_policy_versions import (
    old_retrieve_single_localized_policy_version_async,
)
from ._localized_policy_versions import old_set_default_localized_policy
from ._localized_policy_versions import old_set_default_localized_policy_async
from ._localized_policy_versions import old_update_localized_policy_version
from ._localized_policy_versions import old_update_localized_policy_version_async

from ._localized_policy_versions_with_namespace import create_localized_policy_version
from ._localized_policy_versions_with_namespace import (
    create_localized_policy_version_async,
)
from ._localized_policy_versions_with_namespace import delete_localized_policy
from ._localized_policy_versions_with_namespace import delete_localized_policy_async
from ._localized_policy_versions_with_namespace import (
    public_retrieve_single_localized_policy_version,
)
from ._localized_policy_versions_with_namespace import (
    public_retrieve_single_localized_policy_version_async,
)
from ._localized_policy_versions_with_namespace import request_presigned_url
from ._localized_policy_versions_with_namespace import request_presigned_url_async
from ._localized_policy_versions_with_namespace import (
    retrieve_localized_policy_versions,
)
from ._localized_policy_versions_with_namespace import (
    retrieve_localized_policy_versions_async,
)
from ._localized_policy_versions_with_namespace import (
    retrieve_single_localized_policy_version,
)
from ._localized_policy_versions_with_namespace import (
    retrieve_single_localized_policy_version_async,
)
from ._localized_policy_versions_with_namespace import set_default_localized_policy
from ._localized_policy_versions_with_namespace import (
    set_default_localized_policy_async,
)
from ._localized_policy_versions_with_namespace import update_localized_policy_version
from ._localized_policy_versions_with_namespace import (
    update_localized_policy_version_async,
)

from ._policies import old_retrieve_latest_policies_by_namespace_and_country_public
from ._policies import (
    old_retrieve_latest_policies_by_namespace_and_country_public_async,
)
from ._policies import old_set_default_policy
from ._policies import old_set_default_policy_async
from ._policies import old_update_policy
from ._policies import old_update_policy_async
from ._policies import retrieve_country_list_with_policies
from ._policies import retrieve_country_list_with_policies_async
from ._policies import retrieve_latest_policies
from ._policies import retrieve_latest_policies_async
from ._policies import retrieve_latest_policies_public
from ._policies import retrieve_latest_policies_public_async
from ._policies import retrieve_policies
from ._policies import retrieve_policies_async

from ._policies_with_namespace import delete_policy
from ._policies_with_namespace import delete_policy_async
from ._policies_with_namespace import set_default_policy
from ._policies_with_namespace import set_default_policy_async
from ._policies_with_namespace import update_policy
from ._policies_with_namespace import update_policy_async

from ._policies_with_namespace_v2 import (
    retrieve_latest_policies_by_namespace_and_country_public,
)
from ._policies_with_namespace_v2 import (
    retrieve_latest_policies_by_namespace_and_country_public_async,
)

from ._policy_versions import old_create_policy_version
from ._policy_versions import old_create_policy_version_async
from ._policy_versions import old_publish_policy_version
from ._policy_versions import old_publish_policy_version_async
from ._policy_versions import old_retrieve_single_policy_version
from ._policy_versions import old_retrieve_single_policy_version_async
from ._policy_versions import old_update_policy_version
from ._policy_versions import old_update_policy_version_async

from ._policy_versions_with_namespace import create_policy_version
from ._policy_versions_with_namespace import create_policy_version_async
from ._policy_versions_with_namespace import delete_policy_version
from ._policy_versions_with_namespace import delete_policy_version_async
from ._policy_versions_with_namespace import publish_policy_version
from ._policy_versions_with_namespace import publish_policy_version_async
from ._policy_versions_with_namespace import retrieve_single_policy_version
from ._policy_versions_with_namespace import retrieve_single_policy_version_async
from ._policy_versions_with_namespace import unpublish_policy_version
from ._policy_versions_with_namespace import unpublish_policy_version_async
from ._policy_versions_with_namespace import update_policy_version
from ._policy_versions_with_namespace import update_policy_version_async

from ._user_info import get_user_info_status
from ._user_info import get_user_info_status_async
from ._user_info import invalidate_user_info_cache
from ._user_info import invalidate_user_info_cache_async
from ._user_info import sync_user_info
from ._user_info import sync_user_info_async

from ._utility import check_readiness
from ._utility import check_readiness_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the Fleet Commander."""

__version__ = "1.43.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .development_server_conf_a8e4dd import DevelopmentServerConfigurationCreate
from .development_server_conf_2194f5 import DevelopmentServerConfigurationDelete
from .development_server_conf_282185 import DevelopmentServerConfigurationGet
from .development_server_conf_7b687b import DevelopmentServerConfigurationList
from .development_server_conf_7b687b import (
    SortByEnum as DevelopmentServerConfigurationListSortByEnum,
    SortDirectionEnum as DevelopmentServerConfigurationListSortDirectionEnum,
)
from .development_server_conf_a0c52c import DevelopmentServerConfigurationPatch



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# Custom Service Manager

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.nosqlresource_no_sql_resource_configuration import (
    NosqlresourceNoSQLResourceConfiguration,
)


class ApimodelNoSQLResourceResponse(Model):
    """Apimodel no SQL resource response (apimodel.NoSQLResourceResponse)

    Properties:
        platform_name: (platformName) REQUIRED str

        resource_id: (resourceId) REQUIRED str

        resource_name: (resourceName) REQUIRED str

        resource_type: (resourceType) REQUIRED str

        status: (status) REQUIRED str

        studio_name: (studioName) REQUIRED str

        configuration: (configuration) OPTIONAL NosqlresourceNoSQLResourceConfiguration

        hostnames: (hostnames) OPTIONAL str

        last_rotated_at: (lastRotatedAt) OPTIONAL str

        region: (region) OPTIONAL str

        tls_enabled: (tlsEnabled) OPTIONAL bool
    """

    # region fields

    platform_name: str  # REQUIRED
    resource_id: str  # REQUIRED
    resource_name: str  # REQUIRED
    resource_type: str  # REQUIRED
    status: str  # REQUIRED
    studio_name: str  # REQUIRED
    configuration: NosqlresourceNoSQLResourceConfiguration  # OPTIONAL
    hostnames: str  # OPTIONAL
    last_rotated_at: str  # OPTIONAL
    region: str  # OPTIONAL
    tls_enabled: bool  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_platform_name(self, value: str) -> ApimodelNoSQLResourceResponse:
        self.platform_name = value
        return self

    def with_resource_id(self, value: str) -> ApimodelNoSQLResourceResponse:
        self.resource_id = value
        return self

    def with_resource_name(self, value: str) -> ApimodelNoSQLResourceResponse:
        self.resource_name = value
        return self

    def with_resource_type(self, value: str) -> ApimodelNoSQLResourceResponse:
        self.resource_type = value
        return self

    def with_status(self, value: str) -> ApimodelNoSQLResourceResponse:
        self.status = value
        return self

    def with_studio_name(self, value: str) -> ApimodelNoSQLResourceResponse:
        self.studio_name = value
        return self

    def with_configuration(
        self, value: NosqlresourceNoSQLResourceConfiguration
    ) -> ApimodelNoSQLResourceResponse:
        self.configuration = value
        return self

    def with_hostnames(self, value: str) -> ApimodelNoSQLResourceResponse:
        self.hostnames = value
        return self

    def with_last_rotated_at(self, value: str) -> ApimodelNoSQLResourceResponse:
        self.last_rotated_at = value
        return self

    def with_region(self, value: str) -> ApimodelNoSQLResourceResponse:
        self.region = value
        return self

    def with_tls_enabled(self, value: bool) -> ApimodelNoSQLResourceResponse:
        self.tls_enabled = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "platform_name"):
            result["platformName"] = str(self.platform_name)
        elif include_empty:
            result["platformName"] = ""
        if hasattr(self, "resource_id"):
            result["resourceId"] = str(self.resource_id)
        elif include_empty:
            result["resourceId"] = ""
        if hasattr(self, "resource_name"):
            result["resourceName"] = str(self.resource_name)
        elif include_empty:
            result["resourceName"] = ""
        if hasattr(self, "resource_type"):
            result["resourceType"] = str(self.resource_type)
        elif include_empty:
            result["resourceType"] = ""
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = ""
        if hasattr(self, "studio_name"):
            result["studioName"] = str(self.studio_name)
        elif include_empty:
            result["studioName"] = ""
        if hasattr(self, "configuration"):
            result["configuration"] = self.configuration.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["configuration"] = NosqlresourceNoSQLResourceConfiguration()
        if hasattr(self, "hostnames"):
            result["hostnames"] = str(self.hostnames)
        elif include_empty:
            result["hostnames"] = ""
        if hasattr(self, "last_rotated_at"):
            result["lastRotatedAt"] = str(self.last_rotated_at)
        elif include_empty:
            result["lastRotatedAt"] = ""
        if hasattr(self, "region"):
            result["region"] = str(self.region)
        elif include_empty:
            result["region"] = ""
        if hasattr(self, "tls_enabled"):
            result["tlsEnabled"] = bool(self.tls_enabled)
        elif include_empty:
            result["tlsEnabled"] = False
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        platform_name: str,
        resource_id: str,
        resource_name: str,
        resource_type: str,
        status: str,
        studio_name: str,
        configuration: Optional[NosqlresourceNoSQLResourceConfiguration] = None,
        hostnames: Optional[str] = None,
        last_rotated_at: Optional[str] = None,
        region: Optional[str] = None,
        tls_enabled: Optional[bool] = None,
        **kwargs,
    ) -> ApimodelNoSQLResourceResponse:
        instance = cls()
        instance.platform_name = platform_name
        instance.resource_id = resource_id
        instance.resource_name = resource_name
        instance.resource_type = resource_type
        instance.status = status
        instance.studio_name = studio_name
        if configuration is not None:
            instance.configuration = configuration
        if hostnames is not None:
            instance.hostnames = hostnames
        if last_rotated_at is not None:
            instance.last_rotated_at = last_rotated_at
        if region is not None:
            instance.region = region
        if tls_enabled is not None:
            instance.tls_enabled = tls_enabled
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelNoSQLResourceResponse:
        instance = cls()
        if not dict_:
            return instance
        if "platformName" in dict_ and dict_["platformName"] is not None:
            instance.platform_name = str(dict_["platformName"])
        elif include_empty:
            instance.platform_name = ""
        if "resourceId" in dict_ and dict_["resourceId"] is not None:
            instance.resource_id = str(dict_["resourceId"])
        elif include_empty:
            instance.resource_id = ""
        if "resourceName" in dict_ and dict_["resourceName"] is not None:
            instance.resource_name = str(dict_["resourceName"])
        elif include_empty:
            instance.resource_name = ""
        if "resourceType" in dict_ and dict_["resourceType"] is not None:
            instance.resource_type = str(dict_["resourceType"])
        elif include_empty:
            instance.resource_type = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = ""
        if "studioName" in dict_ and dict_["studioName"] is not None:
            instance.studio_name = str(dict_["studioName"])
        elif include_empty:
            instance.studio_name = ""
        if "configuration" in dict_ and dict_["configuration"] is not None:
            instance.configuration = (
                NosqlresourceNoSQLResourceConfiguration.create_from_dict(
                    dict_["configuration"], include_empty=include_empty
                )
            )
        elif include_empty:
            instance.configuration = NosqlresourceNoSQLResourceConfiguration()
        if "hostnames" in dict_ and dict_["hostnames"] is not None:
            instance.hostnames = str(dict_["hostnames"])
        elif include_empty:
            instance.hostnames = ""
        if "lastRotatedAt" in dict_ and dict_["lastRotatedAt"] is not None:
            instance.last_rotated_at = str(dict_["lastRotatedAt"])
        elif include_empty:
            instance.last_rotated_at = ""
        if "region" in dict_ and dict_["region"] is not None:
            instance.region = str(dict_["region"])
        elif include_empty:
            instance.region = ""
        if "tlsEnabled" in dict_ and dict_["tlsEnabled"] is not None:
            instance.tls_enabled = bool(dict_["tlsEnabled"])
        elif include_empty:
            instance.tls_enabled = False
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelNoSQLResourceResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelNoSQLResourceResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelNoSQLResourceResponse,
        List[ApimodelNoSQLResourceResponse],
        Dict[Any, ApimodelNoSQLResourceResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "platformName": "platform_name",
            "resourceId": "resource_id",
            "resourceName": "resource_name",
            "resourceType": "resource_type",
            "status": "status",
            "studioName": "studio_name",
            "configuration": "configuration",
            "hostnames": "hostnames",
            "lastRotatedAt": "last_rotated_at",
            "region": "region",
            "tlsEnabled": "tls_enabled",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "platformName": True,
            "resourceId": True,
            "resourceName": True,
            "resourceType": True,
            "status": True,
            "studioName": True,
            "configuration": False,
            "hostnames": False,
            "lastRotatedAt": False,
            "region": False,
            "tlsEnabled": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Statistics Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum

from ..models.cycle_override_request import CycleOverrideRequest


class GlobalAggregationMethodEnum(StrEnum):
    LAST = "LAST"
    MAX = "MAX"
    MIN = "MIN"
    TOTAL = "TOTAL"


class SetByEnum(StrEnum):
    CLIENT = "CLIENT"
    SERVER = "SERVER"


class VisibilityEnum(StrEnum):
    SERVERONLY = "SERVERONLY"
    SHOWALL = "SHOWALL"


class StatUpdate(Model):
    """Stat update (StatUpdate)

    Properties:
        cap_cycle_override: (capCycleOverride) OPTIONAL bool

        cycle_ids: (cycleIds) OPTIONAL List[str]

        cycle_overrides: (cycleOverrides) OPTIONAL List[CycleOverrideRequest]

        default_value: (defaultValue) OPTIONAL float

        description: (description) OPTIONAL str

        global_aggregation_method: (globalAggregationMethod) OPTIONAL Union[str, GlobalAggregationMethodEnum]

        ignore_additional_data_on_value_rejected: (ignoreAdditionalDataOnValueRejected) OPTIONAL bool

        increment_only: (incrementOnly) OPTIONAL bool

        is_public: (isPublic) OPTIONAL bool

        maximum: (maximum) OPTIONAL float

        minimum: (minimum) OPTIONAL float

        name: (name) OPTIONAL str

        set_as_global: (setAsGlobal) OPTIONAL bool

        set_by: (setBy) OPTIONAL Union[str, SetByEnum]

        tags: (tags) OPTIONAL List[str]

        visibility: (visibility) OPTIONAL Union[str, VisibilityEnum]
    """

    # region fields

    cap_cycle_override: bool  # OPTIONAL
    cycle_ids: List[str]  # OPTIONAL
    cycle_overrides: List[CycleOverrideRequest]  # OPTIONAL
    default_value: float  # OPTIONAL
    description: str  # OPTIONAL
    global_aggregation_method: Union[str, GlobalAggregationMethodEnum]  # OPTIONAL
    ignore_additional_data_on_value_rejected: bool  # OPTIONAL
    increment_only: bool  # OPTIONAL
    is_public: bool  # OPTIONAL
    maximum: float  # OPTIONAL
    minimum: float  # OPTIONAL
    name: str  # OPTIONAL
    set_as_global: bool  # OPTIONAL
    set_by: Union[str, SetByEnum]  # OPTIONAL
    tags: List[str]  # OPTIONAL
    visibility: Union[str, VisibilityEnum]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_cap_cycle_override(self, value: bool) -> StatUpdate:
        self.cap_cycle_override = value
        return self

    def with_cycle_ids(self, value: List[str]) -> StatUpdate:
        self.cycle_ids = value
        return self

    def with_cycle_overrides(self, value: List[CycleOverrideRequest]) -> StatUpdate:
        self.cycle_overrides = value
        return self

    def with_default_value(self, value: float) -> StatUpdate:
        self.default_value = value
        return self

    def with_description(self, value: str) -> StatUpdate:
        self.description = value
        return self

    def with_global_aggregation_method(
        self, value: Union[str, GlobalAggregationMethodEnum]
    ) -> StatUpdate:
        self.global_aggregation_method = value
        return self

    def with_ignore_additional_data_on_value_rejected(self, value: bool) -> StatUpdate:
        self.ignore_additional_data_on_value_rejected = value
        return self

    def with_increment_only(self, value: bool) -> StatUpdate:
        self.increment_only = value
        return self

    def with_is_public(self, value: bool) -> StatUpdate:
        self.is_public = value
        return self

    def with_maximum(self, value: float) -> StatUpdate:
        self.maximum = value
        return self

    def with_minimum(self, value: float) -> StatUpdate:
        self.minimum = value
        return self

    def with_name(self, value: str) -> StatUpdate:
        self.name = value
        return self

    def with_set_as_global(self, value: bool) -> StatUpdate:
        self.set_as_global = value
        return self

    def with_set_by(self, value: Union[str, SetByEnum]) -> StatUpdate:
        self.set_by = value
        return self

    def with_tags(self, value: List[str]) -> StatUpdate:
        self.tags = value
        return self

    def with_visibility(self, value: Union[str, VisibilityEnum]) -> StatUpdate:
        self.visibility = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "cap_cycle_override"):
            result["capCycleOverride"] = bool(self.cap_cycle_override)
        elif include_empty:
            result["capCycleOverride"] = False
        if hasattr(self, "cycle_ids"):
            result["cycleIds"] = [str(i0) for i0 in self.cycle_ids]
        elif include_empty:
            result["cycleIds"] = []
        if hasattr(self, "cycle_overrides"):
            result["cycleOverrides"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.cycle_overrides
            ]
        elif include_empty:
            result["cycleOverrides"] = []
        if hasattr(self, "default_value"):
            result["defaultValue"] = float(self.default_value)
        elif include_empty:
            result["defaultValue"] = 0.0
        if hasattr(self, "description"):
            result["description"] = str(self.description)
        elif include_empty:
            result["description"] = ""
        if hasattr(self, "global_aggregation_method"):
            result["globalAggregationMethod"] = str(self.global_aggregation_method)
        elif include_empty:
            result["globalAggregationMethod"] = Union[
                str, GlobalAggregationMethodEnum
            ]()
        if hasattr(self, "ignore_additional_data_on_value_rejected"):
            result["ignoreAdditionalDataOnValueRejected"] = bool(
                self.ignore_additional_data_on_value_rejected
            )
        elif include_empty:
            result["ignoreAdditionalDataOnValueRejected"] = False
        if hasattr(self, "increment_only"):
            result["incrementOnly"] = bool(self.increment_only)
        elif include_empty:
            result["incrementOnly"] = False
        if hasattr(self, "is_public"):
            result["isPublic"] = bool(self.is_public)
        elif include_empty:
            result["isPublic"] = False
        if hasattr(self, "maximum"):
            result["maximum"] = float(self.maximum)
        elif include_empty:
            result["maximum"] = 0.0
        if hasattr(self, "minimum"):
            result["minimum"] = float(self.minimum)
        elif include_empty:
            result["minimum"] = 0.0
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "set_as_global"):
            result["setAsGlobal"] = bool(self.set_as_global)
        elif include_empty:
            result["setAsGlobal"] = False
        if hasattr(self, "set_by"):
            result["setBy"] = str(self.set_by)
        elif include_empty:
            result["setBy"] = Union[str, SetByEnum]()
        if hasattr(self, "tags"):
            result["tags"] = [str(i0) for i0 in self.tags]
        elif include_empty:
            result["tags"] = []
        if hasattr(self, "visibility"):
            result["visibility"] = str(self.visibility)
        elif include_empty:
            result["visibility"] = Union[str, VisibilityEnum]()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        cap_cycle_override: Optional[bool] = None,
        cycle_ids: Optional[List[str]] = None,
        cycle_overrides: Optional[List[CycleOverrideRequest]] = None,
        default_value: Optional[float] = None,
        description: Optional[str] = None,
        global_aggregation_method: Optional[
            Union[str, GlobalAggregationMethodEnum]
        ] = None,
        ignore_additional_data_on_value_rejected: Optional[bool] = None,
        increment_only: Optional[bool] = None,
        is_public: Optional[bool] = None,
        maximum: Optional[float] = None,
        minimum: Optional[float] = None,
        name: Optional[str] = None,
        set_as_global: Optional[bool] = None,
        set_by: Optional[Union[str, SetByEnum]] = None,
        tags: Optional[List[str]] = None,
        visibility: Optional[Union[str, VisibilityEnum]] = None,
        **kwargs,
    ) -> StatUpdate:
        instance = cls()
        if cap_cycle_override is not None:
            instance.cap_cycle_override = cap_cycle_override
        if cycle_ids is not None:
            instance.cycle_ids = cycle_ids
        if cycle_overrides is not None:
            instance.cycle_overrides = cycle_overrides
        if default_value is not None:
            instance.default_value = default_value
        if description is not None:
            instance.description = description
        if global_aggregation_method is not None:
            instance.global_aggregation_method = global_aggregation_method
        if ignore_additional_data_on_value_rejected is not None:
            instance.ignore_additional_data_on_value_rejected = (
                ignore_additional_data_on_value_rejected
            )
        if increment_only is not None:
            instance.increment_only = increment_only
        if is_public is not None:
            instance.is_public = is_public
        if maximum is not None:
            instance.maximum = maximum
        if minimum is not None:
            instance.minimum = minimum
        if name is not None:
            instance.name = name
        if set_as_global is not None:
            instance.set_as_global = set_as_global
        if set_by is not None:
            instance.set_by = set_by
        if tags is not None:
            instance.tags = tags
        if visibility is not None:
            instance.visibility = visibility
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> StatUpdate:
        instance = cls()
        if not dict_:
            return instance
        if "capCycleOverride" in dict_ and dict_["capCycleOverride"] is not None:
            instance.cap_cycle_override = bool(dict_["capCycleOverride"])
        elif include_empty:
            instance.cap_cycle_override = False
        if "cycleIds" in dict_ and dict_["cycleIds"] is not None:
            instance.cycle_ids = [str(i0) for i0 in dict_["cycleIds"]]
        elif include_empty:
            instance.cycle_ids = []
        if "cycleOverrides" in dict_ and dict_["cycleOverrides"] is not None:
            instance.cycle_overrides = [
                CycleOverrideRequest.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["cycleOverrides"]
            ]
        elif include_empty:
            instance.cycle_overrides = []
        if "defaultValue" in dict_ and dict_["defaultValue"] is not None:
            instance.default_value = float(dict_["defaultValue"])
        elif include_empty:
            instance.default_value = 0.0
        if "description" in dict_ and dict_["description"] is not None:
            instance.description = str(dict_["description"])
        elif include_empty:
            instance.description = ""
        if (
            "globalAggregationMethod" in dict_
            and dict_["globalAggregationMethod"] is not None
        ):
            instance.global_aggregation_method = str(dict_["globalAggregationMethod"])
        elif include_empty:
            instance.global_aggregation_method = Union[
                str, GlobalAggregationMethodEnum
            ]()
        if (
            "ignoreAdditionalDataOnValueRejected" in dict_
            and dict_["ignoreAdditionalDataOnValueRejected"] is not None
        ):
            instance.ignore_additional_data_on_value_rejected = bool(
                dict_["ignoreAdditionalDataOnValueRejected"]
            )
        elif include_empty:
            instance.ignore_additional_data_on_value_rejected = False
        if "incrementOnly" in dict_ and dict_["incrementOnly"] is not None:
            instance.increment_only = bool(dict_["incrementOnly"])
        elif include_empty:
            instance.increment_only = False
        if "isPublic" in dict_ and dict_["isPublic"] is not None:
            instance.is_public = bool(dict_["isPublic"])
        elif include_empty:
            instance.is_public = False
        if "maximum" in dict_ and dict_["maximum"] is not None:
            instance.maximum = float(dict_["maximum"])
        elif include_empty:
            instance.maximum = 0.0
        if "minimum" in dict_ and dict_["minimum"] is not None:
            instance.minimum = float(dict_["minimum"])
        elif include_empty:
            instance.minimum = 0.0
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "setAsGlobal" in dict_ and dict_["setAsGlobal"] is not None:
            instance.set_as_global = bool(dict_["setAsGlobal"])
        elif include_empty:
            instance.set_as_global = False
        if "setBy" in dict_ and dict_["setBy"] is not None:
            instance.set_by = str(dict_["setBy"])
        elif include_empty:
            instance.set_by = Union[str, SetByEnum]()
        if "tags" in dict_ and dict_["tags"] is not None:
            instance.tags = [str(i0) for i0 in dict_["tags"]]
        elif include_empty:
            instance.tags = []
        if "visibility" in dict_ and dict_["visibility"] is not None:
            instance.visibility = str(dict_["visibility"])
        elif include_empty:
            instance.visibility = Union[str, VisibilityEnum]()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, StatUpdate]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[StatUpdate]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[StatUpdate, List[StatUpdate], Dict[Any, StatUpdate]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "capCycleOverride": "cap_cycle_override",
            "cycleIds": "cycle_ids",
            "cycleOverrides": "cycle_overrides",
            "defaultValue": "default_value",
            "description": "description",
            "globalAggregationMethod": "global_aggregation_method",
            "ignoreAdditionalDataOnValueRejected": "ignore_additional_data_on_value_rejected",
            "incrementOnly": "increment_only",
            "isPublic": "is_public",
            "maximum": "maximum",
            "minimum": "minimum",
            "name": "name",
            "setAsGlobal": "set_as_global",
            "setBy": "set_by",
            "tags": "tags",
            "visibility": "visibility",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "capCycleOverride": False,
            "cycleIds": False,
            "cycleOverrides": False,
            "defaultValue": False,
            "description": False,
            "globalAggregationMethod": False,
            "ignoreAdditionalDataOnValueRejected": False,
            "incrementOnly": False,
            "isPublic": False,
            "maximum": False,
            "minimum": False,
            "name": False,
            "setAsGlobal": False,
            "setBy": False,
            "tags": False,
            "visibility": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "globalAggregationMethod": ["LAST", "MAX", "MIN", "TOTAL"],
            "setBy": ["CLIENT", "SERVER"],
            "visibility": ["SERVERONLY", "SHOWALL"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Statistics Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class CycleOverrideRequest(Model):
    """Cycle override request (CycleOverrideRequest)

    Properties:
        cycle_id: (cycleId) REQUIRED str

        maximum: (maximum) OPTIONAL float

        minimum: (minimum) OPTIONAL float
    """

    # region fields

    cycle_id: str  # REQUIRED
    maximum: float  # OPTIONAL
    minimum: float  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_cycle_id(self, value: str) -> CycleOverrideRequest:
        self.cycle_id = value
        return self

    def with_maximum(self, value: float) -> CycleOverrideRequest:
        self.maximum = value
        return self

    def with_minimum(self, value: float) -> CycleOverrideRequest:
        self.minimum = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "cycle_id"):
            result["cycleId"] = str(self.cycle_id)
        elif include_empty:
            result["cycleId"] = ""
        if hasattr(self, "maximum"):
            result["maximum"] = float(self.maximum)
        elif include_empty:
            result["maximum"] = 0.0
        if hasattr(self, "minimum"):
            result["minimum"] = float(self.minimum)
        elif include_empty:
            result["minimum"] = 0.0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        cycle_id: str,
        maximum: Optional[float] = None,
        minimum: Optional[float] = None,
        **kwargs,
    ) -> CycleOverrideRequest:
        instance = cls()
        instance.cycle_id = cycle_id
        if maximum is not None:
            instance.maximum = maximum
        if minimum is not None:
            instance.minimum = minimum
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> CycleOverrideRequest:
        instance = cls()
        if not dict_:
            return instance
        if "cycleId" in dict_ and dict_["cycleId"] is not None:
            instance.cycle_id = str(dict_["cycleId"])
        elif include_empty:
            instance.cycle_id = ""
        if "maximum" in dict_ and dict_["maximum"] is not None:
            instance.maximum = float(dict_["maximum"])
        elif include_empty:
            instance.maximum = 0.0
        if "minimum" in dict_ and dict_["minimum"] is not None:
            instance.minimum = float(dict_["minimum"])
        elif include_empty:
            instance.minimum = 0.0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, CycleOverrideRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[CycleOverrideRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        CycleOverrideRequest,
        List[CycleOverrideRequest],
        Dict[Any, CycleOverrideRequest],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "cycleId": "cycle_id",
            "maximum": "maximum",
            "minimum": "minimum",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "cycleId": True,
            "maximum": False,
            "minimum": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelsUserInfoResponse(Model):
    """Models user info response (models.UserInfoResponse)

    Properties:
        last_played_time: (lastPlayedTime) OPTIONAL str

        match_pool: (matchPool) OPTIONAL str

        namespace: (namespace) OPTIONAL str

        platform_name: (platformName) OPTIONAL str

        session_template: (sessionTemplate) OPTIONAL str

        user_id: (userID) OPTIONAL str
    """

    # region fields

    last_played_time: str  # OPTIONAL
    match_pool: str  # OPTIONAL
    namespace: str  # OPTIONAL
    platform_name: str  # OPTIONAL
    session_template: str  # OPTIONAL
    user_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_last_played_time(self, value: str) -> ModelsUserInfoResponse:
        self.last_played_time = value
        return self

    def with_match_pool(self, value: str) -> ModelsUserInfoResponse:
        self.match_pool = value
        return self

    def with_namespace(self, value: str) -> ModelsUserInfoResponse:
        self.namespace = value
        return self

    def with_platform_name(self, value: str) -> ModelsUserInfoResponse:
        self.platform_name = value
        return self

    def with_session_template(self, value: str) -> ModelsUserInfoResponse:
        self.session_template = value
        return self

    def with_user_id(self, value: str) -> ModelsUserInfoResponse:
        self.user_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "last_played_time"):
            result["lastPlayedTime"] = str(self.last_played_time)
        elif include_empty:
            result["lastPlayedTime"] = ""
        if hasattr(self, "match_pool"):
            result["matchPool"] = str(self.match_pool)
        elif include_empty:
            result["matchPool"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "platform_name"):
            result["platformName"] = str(self.platform_name)
        elif include_empty:
            result["platformName"] = ""
        if hasattr(self, "session_template"):
            result["sessionTemplate"] = str(self.session_template)
        elif include_empty:
            result["sessionTemplate"] = ""
        if hasattr(self, "user_id"):
            result["userID"] = str(self.user_id)
        elif include_empty:
            result["userID"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        last_played_time: Optional[str] = None,
        match_pool: Optional[str] = None,
        namespace: Optional[str] = None,
        platform_name: Optional[str] = None,
        session_template: Optional[str] = None,
        user_id: Optional[str] = None,
        **kwargs,
    ) -> ModelsUserInfoResponse:
        instance = cls()
        if last_played_time is not None:
            instance.last_played_time = last_played_time
        if match_pool is not None:
            instance.match_pool = match_pool
        if namespace is not None:
            instance.namespace = namespace
        if platform_name is not None:
            instance.platform_name = platform_name
        if session_template is not None:
            instance.session_template = session_template
        if user_id is not None:
            instance.user_id = user_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsUserInfoResponse:
        instance = cls()
        if not dict_:
            return instance
        if "lastPlayedTime" in dict_ and dict_["lastPlayedTime"] is not None:
            instance.last_played_time = str(dict_["lastPlayedTime"])
        elif include_empty:
            instance.last_played_time = ""
        if "matchPool" in dict_ and dict_["matchPool"] is not None:
            instance.match_pool = str(dict_["matchPool"])
        elif include_empty:
            instance.match_pool = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "platformName" in dict_ and dict_["platformName"] is not None:
            instance.platform_name = str(dict_["platformName"])
        elif include_empty:
            instance.platform_name = ""
        if "sessionTemplate" in dict_ and dict_["sessionTemplate"] is not None:
            instance.session_template = str(dict_["sessionTemplate"])
        elif include_empty:
            instance.session_template = ""
        if "userID" in dict_ and dict_["userID"] is not None:
            instance.user_id = str(dict_["userID"])
        elif include_empty:
            instance.user_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsUserInfoResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsUserInfoResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsUserInfoResponse,
        List[ModelsUserInfoResponse],
        Dict[Any, ModelsUserInfoResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "lastPlayedTime": "last_played_time",
            "matchPool": "match_pool",
            "namespace": "namespace",
            "platformName": "platform_name",
            "sessionTemplate": "session_template",
            "userID": "user_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "lastPlayedTime": False,
            "matchPool": False,
            "namespace": False,
            "platformName": False,
            "sessionTemplate": False,
            "userID": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Gdpr Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.gdpr.models import DtoExtendConfigDTO
from ..api.gdpr.models import DtoFinishedDataDeletion
from ..api.gdpr.models import DtoFinishedDataRequest
from ..api.gdpr.models import DtoListFinishedDataDeletion
from ..api.gdpr.models import DtoListFinishedDataRequests
from ..api.gdpr.models import DtoPlatformAccountClosureClientRequest
from ..api.gdpr.models import DtoPlatformAccountClosureClientResponse
from ..api.gdpr.models import DtoPlatformAccountClosureClientsResponse
from ..api.gdpr.models import DtoPlatformAccountClosureMockRequest
from ..api.gdpr.models import DtoS2SDataRequestSummary
from ..api.gdpr.models import DtoServiceConfigDTO
from ..api.gdpr.models import DtoServiceConfigurationDTO
from ..api.gdpr.models import DtoServiceConfigurationUpdateRequest
from ..api.gdpr.models import DtoServicesConfigurationResponse
from ..api.gdpr.models import DtoUserPlatformAccountClosureHistoriesResponse
from ..api.gdpr.models import DtoUserPlatformAccountClosureHistory
from ..api.gdpr.models import DtoXboxBPCertValidationRequest
from ..api.gdpr.models import DtoXboxBPCertValidationResponse
from ..api.gdpr.models import ModelsDataRetrievalResponse
from ..api.gdpr.models import ModelsDeletionData
from ..api.gdpr.models import ModelsDeletionStatus
from ..api.gdpr.models import ModelsListDeletionDataResponse
from ..api.gdpr.models import ModelsListPersonalDataResponse
from ..api.gdpr.models import ModelsPagination
from ..api.gdpr.models import ModelsPersonalData
from ..api.gdpr.models import ModelsRequestDeleteResponse
from ..api.gdpr.models import ModelsS2SDataRetrievalResponse
from ..api.gdpr.models import ModelsS2SRequestDeleteResponse
from ..api.gdpr.models import ModelsS2SUserDataURL
from ..api.gdpr.models import ModelsUserDataURL
from ..api.gdpr.models import ModelsUserPersonalData
from ..api.gdpr.models import ModelsUserPersonalDataResponse
from ..api.gdpr.models import ResponseError


def create_dto_extend_config_dto_example() -> DtoExtendConfigDTO:
    instance = DtoExtendConfigDTO()
    instance.app_name = randomize()
    instance.namespace = randomize("slug")
    return instance


def create_dto_finished_data_deletion_example() -> DtoFinishedDataDeletion:
    instance = DtoFinishedDataDeletion()
    instance.finished_date = randomize("date")
    instance.request_date = randomize("date")
    instance.status = randomize()
    instance.user_id = randomize("uid")
    instance.failed_message = randomize()
    return instance


def create_dto_finished_data_request_example() -> DtoFinishedDataRequest:
    instance = DtoFinishedDataRequest()
    instance.finished_date = randomize("date")
    instance.request_date = randomize("date")
    instance.request_id = randomize()
    instance.status = randomize()
    instance.user_id = randomize("uid")
    instance.data_expiration_date = randomize("date")
    instance.failed_message = randomize()
    return instance


def create_dto_list_finished_data_deletion_example() -> DtoListFinishedDataDeletion:
    instance = DtoListFinishedDataDeletion()
    instance.data = [create_dto_finished_data_deletion_example()]
    return instance


def create_dto_list_finished_data_requests_example() -> DtoListFinishedDataRequests:
    instance = DtoListFinishedDataRequests()
    instance.data = [create_dto_finished_data_request_example()]
    return instance


def create_dto_platform_account_closure_client_request_example() -> (
    DtoPlatformAccountClosureClientRequest
):
    instance = DtoPlatformAccountClosureClientRequest()
    instance.bp_cert = randomize()
    instance.bp_cert_file_name = randomize()
    instance.client_id = randomize("uid")
    instance.password = randomize("password")
    instance.publisher_key = randomize()
    instance.sandbox_id = randomize()
    instance.secret = randomize()
    return instance


def create_dto_platform_account_closure_client_response_example() -> (
    DtoPlatformAccountClosureClientResponse
):
    instance = DtoPlatformAccountClosureClientResponse()
    instance.namespace = randomize("slug")
    instance.platform = randomize()
    instance.updated_at = randomize("int", min_val=1, max_val=1000)
    instance.bp_cert_expire_at = randomize("int", min_val=1, max_val=1000)
    instance.bp_cert_file_name = randomize()
    instance.client_id = randomize("uid")
    instance.publisher_key = randomize()
    instance.sandbox_id = randomize()
    instance.secret = randomize()
    return instance


def create_dto_platform_account_closure_clients_response_example() -> (
    DtoPlatformAccountClosureClientsResponse
):
    instance = DtoPlatformAccountClosureClientsResponse()
    instance.data = [create_dto_platform_account_closure_client_response_example()]
    return instance


def create_dto_platform_account_closure_mock_request_example() -> (
    DtoPlatformAccountClosureMockRequest
):
    instance = DtoPlatformAccountClosureMockRequest()
    instance.platform_user_id = randomize()
    instance.sandbox = randomize()
    instance.start_immediately = randomize("bool")
    return instance


def create_dto_s2s_data_request_summary_example() -> DtoS2SDataRequestSummary:
    instance = DtoS2SDataRequestSummary()
    instance.status = randomize()
    instance.failed_message = randomize()
    instance.url = randomize("url")
    return instance


def create_dto_service_config_dto_example() -> DtoServiceConfigDTO:
    instance = DtoServiceConfigDTO()
    instance.protocol = randomize()
    instance.skip_ack = randomize("bool")
    instance.url = randomize("url")
    return instance


def create_dto_service_configuration_dto_example() -> DtoServiceConfigurationDTO:
    instance = DtoServiceConfigurationDTO()
    instance.id_ = randomize()
    instance.type_ = randomize()
    instance.extend_config = create_dto_extend_config_dto_example()
    instance.package = randomize()
    instance.service_config = create_dto_service_config_dto_example()
    return instance


def create_dto_service_configuration_update_request_example() -> (
    DtoServiceConfigurationUpdateRequest
):
    instance = DtoServiceConfigurationUpdateRequest()
    instance.services = [create_dto_service_configuration_dto_example()]
    return instance


def create_dto_services_configuration_response_example() -> (
    DtoServicesConfigurationResponse
):
    instance = DtoServicesConfigurationResponse()
    instance.services = [create_dto_service_configuration_dto_example()]
    return instance


def create_dto_user_platform_account_closure_histories_response_example() -> (
    DtoUserPlatformAccountClosureHistoriesResponse
):
    instance = DtoUserPlatformAccountClosureHistoriesResponse()
    instance.data = [create_dto_user_platform_account_closure_history_example()]
    instance.pagination = create_models_pagination_example()
    return instance


def create_dto_user_platform_account_closure_history_example() -> (
    DtoUserPlatformAccountClosureHistory
):
    instance = DtoUserPlatformAccountClosureHistory()
    instance.closed_date = randomize("int", min_val=1, max_val=1000)
    instance.environment = randomize()
    instance.namespace = randomize("slug")
    instance.platform = randomize()
    instance.platform_user_id = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_dto_xbox_bp_cert_validation_request_example() -> (
    DtoXboxBPCertValidationRequest
):
    instance = DtoXboxBPCertValidationRequest()
    instance.bp_cert = randomize()
    instance.password = randomize("password")
    return instance


def create_dto_xbox_bp_cert_validation_response_example() -> (
    DtoXboxBPCertValidationResponse
):
    instance = DtoXboxBPCertValidationResponse()
    instance.expiration_date = randomize("int", min_val=1, max_val=1000)
    instance.expired = randomize("bool")
    return instance


def create_models_data_retrieval_response_example() -> ModelsDataRetrievalResponse:
    instance = ModelsDataRetrievalResponse()
    instance.namespace = randomize("slug")
    instance.request_date = randomize("date")
    instance.user_id = randomize("uid")
    return instance


def create_models_deletion_data_example() -> ModelsDeletionData:
    instance = ModelsDeletionData()
    instance.display_name = randomize("slug")
    instance.request_date = randomize("date")
    instance.status = randomize()
    instance.unique_display_name = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_models_deletion_status_example() -> ModelsDeletionStatus:
    instance = ModelsDeletionStatus()
    instance.deletion_date = randomize()
    instance.deletion_status = randomize("bool")
    instance.display_name = randomize("slug")
    instance.status = randomize()
    instance.user_id = randomize("uid")
    instance.execution_date = randomize("date")
    return instance


def create_models_list_deletion_data_response_example() -> (
    ModelsListDeletionDataResponse
):
    instance = ModelsListDeletionDataResponse()
    instance.data = [create_models_deletion_data_example()]
    instance.paging = create_models_pagination_example()
    return instance


def create_models_list_personal_data_response_example() -> (
    ModelsListPersonalDataResponse
):
    instance = ModelsListPersonalDataResponse()
    instance.data = [create_models_personal_data_example()]
    instance.paging = create_models_pagination_example()
    return instance


def create_models_pagination_example() -> ModelsPagination:
    instance = ModelsPagination()
    instance.first = randomize()
    instance.last = randomize()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_models_personal_data_example() -> ModelsPersonalData:
    instance = ModelsPersonalData()
    instance.data_expiration_date = randomize("date")
    instance.display_name = randomize("slug")
    instance.request_date = randomize("date")
    instance.service_errors = {randomize(): randomize()}
    instance.service_statuses = {randomize(): randomize()}
    instance.status = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_models_request_delete_response_example() -> ModelsRequestDeleteResponse:
    instance = ModelsRequestDeleteResponse()
    instance.namespace = randomize("slug")
    instance.user_id = randomize("uid")
    return instance


def create_models_s2s_data_retrieval_response_example() -> (
    ModelsS2SDataRetrievalResponse
):
    instance = ModelsS2SDataRetrievalResponse()
    instance.namespace = randomize("slug")
    instance.request_date = randomize("date")
    instance.request_id = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_models_s2s_request_delete_response_example() -> (
    ModelsS2SRequestDeleteResponse
):
    instance = ModelsS2SRequestDeleteResponse()
    instance.namespace = randomize("slug")
    instance.user_id = randomize("uid")
    return instance


def create_models_s2s_user_data_url_example() -> ModelsS2SUserDataURL:
    instance = ModelsS2SUserDataURL()
    instance.url = randomize("url")
    return instance


def create_models_user_data_url_example() -> ModelsUserDataURL:
    instance = ModelsUserDataURL()
    instance.url = randomize("url")
    return instance


def create_models_user_personal_data_example() -> ModelsUserPersonalData:
    instance = ModelsUserPersonalData()
    instance.data_expiration_date = randomize("date")
    instance.request_date = randomize("date")
    instance.status = randomize()
    return instance


def create_models_user_personal_data_response_example() -> (
    ModelsUserPersonalDataResponse
):
    instance = ModelsUserPersonalDataResponse()
    instance.data = [create_models_user_personal_data_example()]
    instance.paging = create_models_pagination_example()
    return instance


def create_response_error_example() -> ResponseError:
    instance = ResponseError()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    instance.message_variables = {randomize(): randomize()}
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class TopicTypeEnum(StrEnum):
    GROUP = "GROUP"
    PERSONAL = "PERSONAL"


class ModelsMessageRequest(Model):
    """Models message request (models.MessageRequest)

    Properties:
        message: (message) REQUIRED str

        timestamp: (timestamp) OPTIONAL int

        topic_id: (topicId) OPTIONAL str

        topic_type: (topicType) OPTIONAL Union[str, TopicTypeEnum]

        user_id: (userId) OPTIONAL str
    """

    # region fields

    message: str  # REQUIRED
    timestamp: int  # OPTIONAL
    topic_id: str  # OPTIONAL
    topic_type: Union[str, TopicTypeEnum]  # OPTIONAL
    user_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_message(self, value: str) -> ModelsMessageRequest:
        self.message = value
        return self

    def with_timestamp(self, value: int) -> ModelsMessageRequest:
        self.timestamp = value
        return self

    def with_topic_id(self, value: str) -> ModelsMessageRequest:
        self.topic_id = value
        return self

    def with_topic_type(self, value: Union[str, TopicTypeEnum]) -> ModelsMessageRequest:
        self.topic_type = value
        return self

    def with_user_id(self, value: str) -> ModelsMessageRequest:
        self.user_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "message"):
            result["message"] = str(self.message)
        elif include_empty:
            result["message"] = ""
        if hasattr(self, "timestamp"):
            result["timestamp"] = int(self.timestamp)
        elif include_empty:
            result["timestamp"] = 0
        if hasattr(self, "topic_id"):
            result["topicId"] = str(self.topic_id)
        elif include_empty:
            result["topicId"] = ""
        if hasattr(self, "topic_type"):
            result["topicType"] = str(self.topic_type)
        elif include_empty:
            result["topicType"] = Union[str, TopicTypeEnum]()
        if hasattr(self, "user_id"):
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        message: str,
        timestamp: Optional[int] = None,
        topic_id: Optional[str] = None,
        topic_type: Optional[Union[str, TopicTypeEnum]] = None,
        user_id: Optional[str] = None,
        **kwargs,
    ) -> ModelsMessageRequest:
        instance = cls()
        instance.message = message
        if timestamp is not None:
            instance.timestamp = timestamp
        if topic_id is not None:
            instance.topic_id = topic_id
        if topic_type is not None:
            instance.topic_type = topic_type
        if user_id is not None:
            instance.user_id = user_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsMessageRequest:
        instance = cls()
        if not dict_:
            return instance
        if "message" in dict_ and dict_["message"] is not None:
            instance.message = str(dict_["message"])
        elif include_empty:
            instance.message = ""
        if "timestamp" in dict_ and dict_["timestamp"] is not None:
            instance.timestamp = int(dict_["timestamp"])
        elif include_empty:
            instance.timestamp = 0
        if "topicId" in dict_ and dict_["topicId"] is not None:
            instance.topic_id = str(dict_["topicId"])
        elif include_empty:
            instance.topic_id = ""
        if "topicType" in dict_ and dict_["topicType"] is not None:
            instance.topic_type = str(dict_["topicType"])
        elif include_empty:
            instance.topic_type = Union[str, TopicTypeEnum]()
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsMessageRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsMessageRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsMessageRequest,
        List[ModelsMessageRequest],
        Dict[Any, ModelsMessageRequest],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "message": "message",
            "timestamp": "timestamp",
            "topicId": "topic_id",
            "topicType": "topic_type",
            "userId": "user_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "message": True,
            "timestamp": False,
            "topicId": False,
            "topicType": False,
            "userId": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "topicType": ["GROUP", "PERSONAL"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ResponseError

from ..operations.session_storage import AdminDeleteUserSessionStorage
from ..operations.session_storage import AdminReadPartySessionStorage
from ..operations.session_storage import AdminReadSessionStorage
from ..operations.session_storage import AdminReadUserSessionStorage
from ..operations.session_storage import PublicReadPartySessionStorage
from ..operations.session_storage import PublicUpdateInsertPartySessionStorage
from ..operations.session_storage import PublicUpdateInsertPartySessionStorageReserved
from ..operations.session_storage import PublicUpdateInsertSessionStorage
from ..operations.session_storage import PublicUpdateInsertSessionStorageLeader


@same_doc_as(AdminDeleteUserSessionStorage)
def admin_delete_user_session_storage(
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete Session Storage. (adminDeleteUserSessionStorage)


    Delete Session Storage By sessionID
    Session Storage feature only available for Gamesession

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/sessions/{sessionId}/storage

        method: DELETE

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminDeleteUserSessionStorage.create(
        session_id=session_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeleteUserSessionStorage)
async def admin_delete_user_session_storage_async(
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete Session Storage. (adminDeleteUserSessionStorage)


    Delete Session Storage By sessionID
    Session Storage feature only available for Gamesession

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/sessions/{sessionId}/storage

        method: DELETE

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminDeleteUserSessionStorage.create(
        session_id=session_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminReadPartySessionStorage)
def admin_read_party_session_storage(
    party_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Read Party Session Storage. (adminReadPartySessionStorage)

    Read Party Session Storage by partyID
    Party Storage example:
    ```
    {
    "reserved": {
    "userID1": {"key": "value"},
    "userID2": {"key": "value"},
    ...
    }
    }
    ```

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/parties/{partyId}/storage

        method: GET

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        party_id: (partyId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminReadPartySessionStorage.create(
        party_id=party_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminReadPartySessionStorage)
async def admin_read_party_session_storage_async(
    party_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Read Party Session Storage. (adminReadPartySessionStorage)

    Read Party Session Storage by partyID
    Party Storage example:
    ```
    {
    "reserved": {
    "userID1": {"key": "value"},
    "userID2": {"key": "value"},
    ...
    }
    }
    ```

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/parties/{partyId}/storage

        method: GET

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        party_id: (partyId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminReadPartySessionStorage.create(
        party_id=party_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminReadSessionStorage)
def admin_read_session_storage(
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Read Session Storage. (adminReadSessionStorage)


    Read Session Storage by sessionID
    Session Storage feature only available for Gamesession

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/sessions/{sessionId}/storage

        method: GET

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminReadSessionStorage.create(
        session_id=session_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminReadSessionStorage)
async def admin_read_session_storage_async(
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Read Session Storage. (adminReadSessionStorage)


    Read Session Storage by sessionID
    Session Storage feature only available for Gamesession

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/sessions/{sessionId}/storage

        method: GET

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminReadSessionStorage.create(
        session_id=session_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminReadUserSessionStorage)
def admin_read_user_session_storage(
    session_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Read Session Storage User. (adminReadUserSessionStorage)


    Read Session Storage by sessionID and userID
    Session Storage feature only available for Gamesession

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/sessions/{sessionId}/storage/users/{userId}

        method: GET

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminReadUserSessionStorage.create(
        session_id=session_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminReadUserSessionStorage)
async def admin_read_user_session_storage_async(
    session_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Read Session Storage User. (adminReadUserSessionStorage)


    Read Session Storage by sessionID and userID
    Session Storage feature only available for Gamesession

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/sessions/{sessionId}/storage/users/{userId}

        method: GET

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminReadUserSessionStorage.create(
        session_id=session_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicReadPartySessionStorage)
def public_read_party_session_storage(
    party_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Read Party Session Storage. (publicReadPartySessionStorage)

    Read Party Session Storage by partyID (with reserved and member).
    Contains "reserved" when Update Insert Party Session Reserved Storage User.
    Contains "member" when Update Insert Party Session Storage User.
    Party Storage example:
    ```
    {
    "reserved": {
    "userID1": {"key": "value"},
    "userID2": {"key": "value"},
    ...
    },
    "member": {
    "userID1": {"key": "value"},
    "userID2": {"key": "value"},
    ...
    }
    }
    ```

    Properties:
        url: /session/v1/public/namespaces/{namespace}/parties/{partyId}/storage

        method: GET

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        party_id: (partyId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicReadPartySessionStorage.create(
        party_id=party_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicReadPartySessionStorage)
async def public_read_party_session_storage_async(
    party_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Read Party Session Storage. (publicReadPartySessionStorage)

    Read Party Session Storage by partyID (with reserved and member).
    Contains "reserved" when Update Insert Party Session Reserved Storage User.
    Contains "member" when Update Insert Party Session Storage User.
    Party Storage example:
    ```
    {
    "reserved": {
    "userID1": {"key": "value"},
    "userID2": {"key": "value"},
    ...
    },
    "member": {
    "userID1": {"key": "value"},
    "userID2": {"key": "value"},
    ...
    }
    }
    ```

    Properties:
        url: /session/v1/public/namespaces/{namespace}/parties/{partyId}/storage

        method: GET

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        party_id: (partyId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicReadPartySessionStorage.create(
        party_id=party_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicUpdateInsertPartySessionStorage)
def public_update_insert_party_session_storage(
    body: Dict[str, Any],
    party_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Insert Party Session Storage User. (publicUpdateInsertPartySessionStorage)

    Update Insert Party Session Storage User. User can only update or insert their own party storage (non-immutable).
    can store generic json
    example json can store :
    ```
    {
    "key": "value",
    "number": 123,
    }
    ```
    The data will be stored on the "member" storage field
    example stored data :
    ```
    {
    "member": {
    "userID1": {"key": "value"},
    "userID2": {"key": "value"},
    ...
    }
    }
    ```

    Properties:
        url: /session/v1/public/namespaces/{namespace}/parties/{partyId}/storage/users/{userId}

        method: PATCH

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED Dict[str, Any] in body

        namespace: (namespace) REQUIRED str in path

        party_id: (partyId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateInsertPartySessionStorage.create(
        body=body,
        party_id=party_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicUpdateInsertPartySessionStorage)
async def public_update_insert_party_session_storage_async(
    body: Dict[str, Any],
    party_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Insert Party Session Storage User. (publicUpdateInsertPartySessionStorage)

    Update Insert Party Session Storage User. User can only update or insert their own party storage (non-immutable).
    can store generic json
    example json can store :
    ```
    {
    "key": "value",
    "number": 123,
    }
    ```
    The data will be stored on the "member" storage field
    example stored data :
    ```
    {
    "member": {
    "userID1": {"key": "value"},
    "userID2": {"key": "value"},
    ...
    }
    }
    ```

    Properties:
        url: /session/v1/public/namespaces/{namespace}/parties/{partyId}/storage/users/{userId}

        method: PATCH

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED Dict[str, Any] in body

        namespace: (namespace) REQUIRED str in path

        party_id: (partyId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateInsertPartySessionStorage.create(
        body=body,
        party_id=party_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicUpdateInsertPartySessionStorageReserved)
def public_update_insert_party_session_storage_reserved(
    body: Dict[str, Any],
    party_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Insert Party Session Reserved Storage User. (publicUpdateInsertPartySessionStorageReserved)

    **For Internal Use Only**
    Update Insert Party Session Reserved Storage User. User can only update or insert their own reserve storage (non-immutable).
    can store generic json
    example json can store :
    ```
    {
    "key": "value",
    "number": 123,
    }
    ```
    The data will be stored on the "reserved" storage field
    example stored data :
    ```
    {
    "reserved": {
    "userID1": {"key": "value"},
    "userID2": {"key": "value"},
    ...
    }
    }
    ```

    Properties:
        url: /session/v1/public/namespaces/{namespace}/parties/{partyId}/storage/users/{userId}/reserved

        method: PATCH

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED Dict[str, Any] in body

        namespace: (namespace) REQUIRED str in path

        party_id: (partyId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateInsertPartySessionStorageReserved.create(
        body=body,
        party_id=party_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicUpdateInsertPartySessionStorageReserved)
async def public_update_insert_party_session_storage_reserved_async(
    body: Dict[str, Any],
    party_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Insert Party Session Reserved Storage User. (publicUpdateInsertPartySessionStorageReserved)

    **For Internal Use Only**
    Update Insert Party Session Reserved Storage User. User can only update or insert their own reserve storage (non-immutable).
    can store generic json
    example json can store :
    ```
    {
    "key": "value",
    "number": 123,
    }
    ```
    The data will be stored on the "reserved" storage field
    example stored data :
    ```
    {
    "reserved": {
    "userID1": {"key": "value"},
    "userID2": {"key": "value"},
    ...
    }
    }
    ```

    Properties:
        url: /session/v1/public/namespaces/{namespace}/parties/{partyId}/storage/users/{userId}/reserved

        method: PATCH

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED Dict[str, Any] in body

        namespace: (namespace) REQUIRED str in path

        party_id: (partyId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateInsertPartySessionStorageReserved.create(
        body=body,
        party_id=party_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicUpdateInsertSessionStorage)
def public_update_insert_session_storage(
    body: Dict[str, Any],
    session_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Insert Session Storage User. (publicUpdateInsertSessionStorage)


    Update Insert Session Storage User. user can only update or insert user session storage data itself.
    can store generic json
    example json can store :
    {
    "storage": {
    "storage": 1
    },
    "data": 123
    }
    game Admin can update or insert session storage
    Session Storage feature only available for Gamesession

    Properties:
        url: /session/v1/public/namespaces/{namespace}/sessions/{sessionId}/storage/users/{userId}

        method: PATCH

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED Dict[str, Any] in body

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateInsertSessionStorage.create(
        body=body,
        session_id=session_id,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicUpdateInsertSessionStorage)
async def public_update_insert_session_storage_async(
    body: Dict[str, Any],
    session_id: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Insert Session Storage User. (publicUpdateInsertSessionStorage)


    Update Insert Session Storage User. user can only update or insert user session storage data itself.
    can store generic json
    example json can store :
    {
    "storage": {
    "storage": 1
    },
    "data": 123
    }
    game Admin can update or insert session storage
    Session Storage feature only available for Gamesession

    Properties:
        url: /session/v1/public/namespaces/{namespace}/sessions/{sessionId}/storage/users/{userId}

        method: PATCH

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED Dict[str, Any] in body

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateInsertSessionStorage.create(
        body=body,
        session_id=session_id,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicUpdateInsertSessionStorageLeader)
def public_update_insert_session_storage_leader(
    body: Dict[str, Any],
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Insert Session Storage Leader. (publicUpdateInsertSessionStorageLeader)


    Update Insert Session Storage Leader. only Leader can update or insert user session storage data Leader.
    can store generic json
    example json can store :
    {
    "leader": {
    "leader": 1
    },
    "data": 123
    }
    game Admin can update or insert session storage
    Session Storage feature only available for Gamesession

    Properties:
        url: /session/v1/public/namespaces/{namespace}/sessions/{sessionId}/storage/leader

        method: PATCH

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED Dict[str, Any] in body

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateInsertSessionStorageLeader.create(
        body=body,
        session_id=session_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicUpdateInsertSessionStorageLeader)
async def public_update_insert_session_storage_leader_async(
    body: Dict[str, Any],
    session_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Insert Session Storage Leader. (publicUpdateInsertSessionStorageLeader)


    Update Insert Session Storage Leader. only Leader can update or insert user session storage data Leader.
    can store generic json
    example json can store :
    {
    "leader": {
    "leader": 1
    },
    "data": 123
    }
    game Admin can update or insert session storage
    Session Storage feature only available for Gamesession

    Properties:
        url: /session/v1/public/namespaces/{namespace}/sessions/{sessionId}/storage/leader

        method: PATCH

        tags: ["Session Storage"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED Dict[str, Any] in body

        namespace: (namespace) REQUIRED str in path

        session_id: (sessionId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicUpdateInsertSessionStorageLeader.create(
        body=body,
        session_id=session_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# Custom Service Manager

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ApimodelTopicSubscription(Model):
    """Apimodel topic subscription (apimodel.TopicSubscription)

    Properties:
        app_id: (appId) REQUIRED str

        app_name: (appName) REQUIRED str

        queue_id: (queueId) REQUIRED str

        subscription_arn: (subscriptionArn) REQUIRED str

        subscription_id: (subscriptionId) REQUIRED str

        subscription_time: (subscriptionTime) REQUIRED str
    """

    # region fields

    app_id: str  # REQUIRED
    app_name: str  # REQUIRED
    queue_id: str  # REQUIRED
    subscription_arn: str  # REQUIRED
    subscription_id: str  # REQUIRED
    subscription_time: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_app_id(self, value: str) -> ApimodelTopicSubscription:
        self.app_id = value
        return self

    def with_app_name(self, value: str) -> ApimodelTopicSubscription:
        self.app_name = value
        return self

    def with_queue_id(self, value: str) -> ApimodelTopicSubscription:
        self.queue_id = value
        return self

    def with_subscription_arn(self, value: str) -> ApimodelTopicSubscription:
        self.subscription_arn = value
        return self

    def with_subscription_id(self, value: str) -> ApimodelTopicSubscription:
        self.subscription_id = value
        return self

    def with_subscription_time(self, value: str) -> ApimodelTopicSubscription:
        self.subscription_time = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "app_id"):
            result["appId"] = str(self.app_id)
        elif include_empty:
            result["appId"] = ""
        if hasattr(self, "app_name"):
            result["appName"] = str(self.app_name)
        elif include_empty:
            result["appName"] = ""
        if hasattr(self, "queue_id"):
            result["queueId"] = str(self.queue_id)
        elif include_empty:
            result["queueId"] = ""
        if hasattr(self, "subscription_arn"):
            result["subscriptionArn"] = str(self.subscription_arn)
        elif include_empty:
            result["subscriptionArn"] = ""
        if hasattr(self, "subscription_id"):
            result["subscriptionId"] = str(self.subscription_id)
        elif include_empty:
            result["subscriptionId"] = ""
        if hasattr(self, "subscription_time"):
            result["subscriptionTime"] = str(self.subscription_time)
        elif include_empty:
            result["subscriptionTime"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        app_id: str,
        app_name: str,
        queue_id: str,
        subscription_arn: str,
        subscription_id: str,
        subscription_time: str,
        **kwargs,
    ) -> ApimodelTopicSubscription:
        instance = cls()
        instance.app_id = app_id
        instance.app_name = app_name
        instance.queue_id = queue_id
        instance.subscription_arn = subscription_arn
        instance.subscription_id = subscription_id
        instance.subscription_time = subscription_time
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelTopicSubscription:
        instance = cls()
        if not dict_:
            return instance
        if "appId" in dict_ and dict_["appId"] is not None:
            instance.app_id = str(dict_["appId"])
        elif include_empty:
            instance.app_id = ""
        if "appName" in dict_ and dict_["appName"] is not None:
            instance.app_name = str(dict_["appName"])
        elif include_empty:
            instance.app_name = ""
        if "queueId" in dict_ and dict_["queueId"] is not None:
            instance.queue_id = str(dict_["queueId"])
        elif include_empty:
            instance.queue_id = ""
        if "subscriptionArn" in dict_ and dict_["subscriptionArn"] is not None:
            instance.subscription_arn = str(dict_["subscriptionArn"])
        elif include_empty:
            instance.subscription_arn = ""
        if "subscriptionId" in dict_ and dict_["subscriptionId"] is not None:
            instance.subscription_id = str(dict_["subscriptionId"])
        elif include_empty:
            instance.subscription_id = ""
        if "subscriptionTime" in dict_ and dict_["subscriptionTime"] is not None:
            instance.subscription_time = str(dict_["subscriptionTime"])
        elif include_empty:
            instance.subscription_time = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelTopicSubscription]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelTopicSubscription]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelTopicSubscription,
        List[ApimodelTopicSubscription],
        Dict[Any, ApimodelTopicSubscription],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "appId": "app_id",
            "appName": "app_name",
            "queueId": "queue_id",
            "subscriptionArn": "subscription_arn",
            "subscriptionId": "subscription_id",
            "subscriptionTime": "subscription_time",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "appId": True,
            "appName": True,
            "queueId": True,
            "subscriptionArn": True,
            "subscriptionId": True,
            "subscriptionTime": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Service."""

__version__ = "3.29.3"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_delete_platform_c_b8f2c5 import AdminDeletePlatformCredentials
from .admin_delete_platform_c_78003c import AdminDeletePlatformCredentialsByPlatformId
from .admin_delete_platform_c_78003c import (
    PlatformIdEnum as AdminDeletePlatformCredentialsByPlatformIdPlatformIdEnum,
)
from .admin_get_platform_credentials import AdminGetPlatformCredentials
from .admin_sync_platform_cre_f4389d import AdminSyncPlatformCredentials
from .admin_sync_platform_cre_f4389d import (
    PlatformIdEnum as AdminSyncPlatformCredentialsPlatformIdEnum,
)
from .admin_update_platform_c_5be87f import AdminUpdatePlatformCredentials
from .admin_upload_platform_c_50325d import AdminUploadPlatformCredentials
from .admin_upload_platform_c_50325d import (
    PlatformIdEnum as AdminUploadPlatformCredentialsPlatformIdEnum,
)
